@@ -432,27 +432,27 @@ gps_mask_t PrintSERPacket(struct gps_device_t *session, unsigned char pkt_id,
         case 1:
         default:
             // no fix
-            session->newdata.status = STATUS_NO_FIX;
+            session->newdata.status = STATUS_UNK;
             session->newdata.mode = MODE_NO_FIX;
             break;
         case 2:
             // 2D fix
-            session->newdata.status = STATUS_FIX;
+            session->newdata.status = STATUS_GPS;
             session->newdata.mode = MODE_2D;
             break;
         case 3:
             // 3D fix
-            session->newdata.status = STATUS_FIX;
+            session->newdata.status = STATUS_GPS;
             session->newdata.mode = MODE_3D;
             break;
         case 4:
             // 2D Differential fix
-            session->newdata.status = STATUS_DGPS_FIX;
+            session->newdata.status = STATUS_DGPS;
             session->newdata.mode = MODE_2D;
             break;
         case 5:
             // 3D differential fix
-            session->newdata.status = STATUS_DGPS_FIX;
+            session->newdata.status = STATUS_DGPS;
             session->newdata.mode = MODE_3D;
             break;
         }
@@ -939,45 +939,43 @@ static bool garmin_usb_detect(struct gps_device_t *session UNUSED)
      * fronm being rudely elbowed aside by this one if they happen
      * to be trying to coexist with the Garmin.
      */
-    if (session->sourcetype != source_usb)
+    if (SOURCE_USB != session->sourcetype) {
         return false;
-    else {
-#ifdef HAVE_LIBUSB
-        if (!is_usb_device(session->gpsdata.dev.path, 0x091e, 0x0003,
-                &session->context->errout))
-            return false;
-
-        if (!gpsd_set_raw(session)) {
-            GPSD_LOG(LOG_ERROR, &session->context->errout,
-                     "Garmin: garmin_usb_detect: error changing port attributes: %s\n",
-                     strerror(errno));
-            return false;
-        }
-
-        if (sizeof(session->driver.garmin.Buffer) < sizeof(Packet_t)) {
-            /* dunno how this happens, but it does on some compilers */
-            GPSD_LOG(LOG_ERROR, &session->context->errout,
-                     "Garmin: garmin_usb_detect: Compile error, garmin.Buffer too small.\n");
-            return false;
-        }
-
-        // FIXME!!! needs to use libusb totally and move garmin_gps aside */
-        // set Mode 1, mode 0 is broken somewhere past 2.6.14
-        // but how?
-        GPSD_LOG(LOG_PROG, &session->context->errout,
-                 "Garmin: Set garmin_gps driver mode = 0\n");
-        Build_Send_USB_Packet(session, GARMIN_LAYERID_PRIVATE,
-                              PRIV_PKTID_SET_MODE, 4, MODE_GARMIN_SERIAL);
-        // expect no return packet !?
-
-        return true;
-#else
-        return false;
-#endif /* HAVE_LIBUSB */
     }
-#else
-    return false;
+
+#ifdef HAVE_LIBUSB
+    if (!is_usb_device(session->gpsdata.dev.path, 0x091e, 0x0003,
+            &session->context->errout))
+        return false;
+
+    if (!gpsd_set_raw(session)) {
+        GPSD_LOG(LOG_ERROR, &session->context->errout,
+                 "Garmin: garmin_usb_detect: error changing port "
+                 "attributes: %s\n",
+                 strerror(errno));
+        return false;
+    }
+
+    if (sizeof(session->driver.garmin.Buffer) < sizeof(Packet_t)) {
+        /* dunno how this happens, but it does on some compilers */
+        GPSD_LOG(LOG_ERROR, &session->context->errout,
+                 "Garmin: garmin_usb_detect: Compile error, garmin.Buffer too small.\n");
+        return false;
+    }
+
+    // FIXME!!! needs to use libusb totally and move garmin_gps aside */
+    // set Mode 1, mode 0 is broken somewhere past 2.6.14
+    // but how?
+    GPSD_LOG(LOG_PROG, &session->context->errout,
+             "Garmin: Set garmin_gps driver mode = 0\n");
+    Build_Send_USB_Packet(session, GARMIN_LAYERID_PRIVATE,
+                          PRIV_PKTID_SET_MODE, 4, MODE_GARMIN_SERIAL);
+    // expect no return packet !?
+
+    return true;
+#endif /* HAVE_LIBUSB */
 #endif /* __linux__ */
+    return false;
 }
 
 static void garmin_event_hook(struct gps_device_t *session, event_t event)
@@ -1232,7 +1230,7 @@ static ssize_t garmin_control_send(struct gps_device_t *session,
 
 static double garmin_time_offset(struct gps_device_t *session)
 {
-    if (session->sourcetype == source_usb) {
+    if (SOURCE_USB == session->sourcetype) {
         return 0.035;           /* Garmin USB, expect +/- 40mS jitter */
     }
     /* only two sentences ships time */
@@ -1255,23 +1253,23 @@ static double garmin_time_offset(struct gps_device_t *session)
 /* *INDENT-OFF* */
 const struct gps_type_t driver_garmin_usb_binary =
 {
-    .type_name      = "Garmin USB binary",      /* full name of type */
-    .packet_type    = GARMIN_PACKET,    /* associated lexer packet type */
-    .flags          = DRIVER_STICKY,    /* remember this */
-    .trigger        = NULL,             /* no trigger, it has a probe */
-    .channels       = GARMIN_CHANNELS,  /* consumer-grade GPS */
-    .probe_detect   = garmin_usb_detect,/* how to detect at startup time */
-    .get_packet     = generic_get,      /* how to grab a packet */
-    .parse_packet   = garmin_ser_parse, /* parse message packets */
-    .rtcm_writer    = NULL,             /* don't send DGPS corrections */
-    .init_query     = NULL,             /* non-perturbing initial query */
-    .event_hook     = garmin_event_hook,/* lifetime ebent handler */
-    .speed_switcher = NULL,             /* no speed switcher */
-    .mode_switcher  = NULL,             /* Garmin USB Binary has no NMEA */
-    .rate_switcher  = NULL,             /* no sample-rate switcher */
+    .type_name      = "Garmin USB binary",  // full name of type
+    .packet_type    = GARMIN_PACKET,        // associated lexer packet type
+    .flags          = DRIVER_STICKY,        // remember this
+    .trigger        = NULL,                 // no trigger, it has a probe
+    .channels       = GARMIN_CHANNELS,      // consumer-grade GPS
+    .probe_detect   = garmin_usb_detect,    // how to detect at startup time
+    .get_packet     = generic_get,          // how to grab a packet
+    .parse_packet   = garmin_ser_parse,     // parse message packets
+    .rtcm_writer    = NULL,                 // don't send DGPS corrections
+    .init_query     = NULL,                 // non-perturbing initial query
+    .event_hook     = garmin_event_hook,    // lifetime ebent handler
+    .speed_switcher = NULL,                 // no speed switcher
+    .mode_switcher  = NULL,                 // Garmin USB Binary has no NMEA
+    .rate_switcher  = NULL,                 // no sample-rate switcher
     .min_cycle.tv_sec  = 0,
-    .min_cycle.tv_nsec = 10000000,      /* 10Hz */
-    .control_send   = garmin_control_send,      /* send raw bytes */
+    .min_cycle.tv_nsec = 10000000,          // 10Hz
+    .control_send   = garmin_control_send,  // send raw bytes
     .time_offset     = garmin_time_offset,
 };
 /* *INDENT-ON* */
@@ -1279,25 +1277,25 @@ const struct gps_type_t driver_garmin_usb_binary =
 /* *INDENT-OFF* */
 const struct gps_type_t driver_garmin_ser_binary =
 {
-    .type_name      = "Garmin Serial binary",   /* full name of type */
-    .packet_type    = GARMIN_PACKET,    /* associated lexer packet type */
-    .flags          = DRIVER_STICKY,    /* remember this */
-    .trigger        = NULL,             /* no trigger, it has a probe */
-    .channels       = GARMIN_CHANNELS,  /* consumer-grade GPS */
-    .probe_detect   = NULL,             /* how to detect at startup time */
-    .get_packet     = generic_get,       /* how to grab a packet */
-    .parse_packet   = garmin_ser_parse, /* parse message packets */
-    .rtcm_writer    = NULL,             /* don't send DGPS corrections */
-    .init_query     = NULL,             /* non-perturbing initial query */
+    .type_name      = "Garmin Serial binary",  // full name of type
+    .packet_type    = GARMIN_PACKET,           // associated lexer packet type
+    .flags          = DRIVER_STICKY,           // remember this
+    .trigger        = NULL,                    // no trigger, it has a probe
+    .channels       = GARMIN_CHANNELS,         // consumer-grade GPS
+    .probe_detect   = NULL,                    // how to detect at startup time
+    .get_packet     = generic_get,             // how to grab a packet
+    .parse_packet   = garmin_ser_parse,        // parse message packets
+    .rtcm_writer    = NULL,                    // don't send DGPS corrections
+    .init_query     = NULL,                    // non-perturbing initial query
     /* The Garmin Gek0 301 needs to be kicked to start sending binary.
      * like the Garmin USB. */
-    .event_hook     = garmin_event_hook,        /* lifetime event handler */
-    .speed_switcher = NULL,             /* no speed switcher */
-    .mode_switcher  = garmin_switcher,  /* how to change modes */
-    .rate_switcher  = NULL,             /* no sample-rate switcher */
+    .event_hook     = garmin_event_hook,       // lifetime event handler
+    .speed_switcher = NULL,                    // no speed switcher
+    .mode_switcher  = garmin_switcher,         // how to change modes
+    .rate_switcher  = NULL,                    // no sample-rate switcher
     .min_cycle.tv_sec  = 0,
-    .min_cycle.tv_nsec = 10000000,      /* 10Hz */
-    .control_send   = garmin_control_send,      /* send raw bytes */
+    .min_cycle.tv_nsec = 10000000,             // 10Hz
+    .control_send   = garmin_control_send,     // send raw bytes
     .time_offset     = garmin_time_offset,
 };
 /* *INDENT-ON* */
